@@ -51,26 +51,29 @@ class StdOutTarget(TargetAbstract):
 
 class LogFileTarget(TargetAbstract):
     
-    def __init__(self, filepath, filename='log') -> None:
+    def __init__(self, file) -> None:
 
-        if not os.path.exists(filepath):
-            raise ValueError('Path does not exist.')
+        if not os.path.exists(file):
+            raise ValueError(f'Path {file} does not exist.')
         
-        self.file = os.path.join(filepath, filename)
+        if not os.path.isfile(file):
+            raise ValueError(f'Path {file} does not lead to a file.')
+
+        self.file = file
 
     def log(self, message: str, type: MessageTypes = MessageTypes.INFO, level: int=0):
 
-        if not type == MessageTypes.INFO:
-            message = f'{self.get_timestamp()} {type.name} - {message}'
-        else: 
+        if type == MessageTypes.INFO:
             message = f'{self.get_timestamp()} - {message}'
+        else:
+            message = f'{self.get_timestamp()} {type.name} - {message}'            
 
         for level in range(level):
             message = '\t' + message
 
         message += '\n'
 
-        with open(self.file, mode='w') as file:
+        with open(self.file, mode='a') as file:
             file.write(message)
 
 
@@ -87,6 +90,10 @@ class Logger:
         
         self.targets = targets
 
+    def add_target(self, target: TargetAbstract) -> None:
+
+        self.targets.append(target)
+
     def log_success(self, message, level=0):
         
         self.log(
